@@ -9,6 +9,7 @@ class Predictor():
         self.config = config
         self.min_size = config['dataset_config']['min_size_test']
         self.max_size = config['dataset_config']['max_size_test']
+        self.classes = config['dataset_config']['classes']
 
         self.model = FasterRCNN(config['backbone'],
                         config['fpn_config'],
@@ -32,4 +33,18 @@ class Predictor():
         pred = self.model.predict(img, min_size=self.min_size, max_size=self.max_size, return_roi=return_roi, include_bg=include_bg)
         return pred
 
+    
+    def predict_bbox(self, img):
+        img = img.transpose((2, 0, 1))
+        bboxes, labels, scores = self.model.predict(img, min_size=self.min_size, max_size=self.max_size)
+        
+        results = []
+        for box, prob, clazz in zip(bboxes, scores, labels):
+            y1, x1, y2, x2 = box
+            w = x2 - x1
+            h = y2 - y1
+            r = {'x': x1, 'y': y1, 'w': w, 'h': h, 'prob': prob, 'name': self.classes[clazz]}
+            results.append(r)
+
+        return results
 
